// For Instructables Apple II Game Paddle or Joystick
// John R. Conrad
// January 19. 2025

// This is written for the Arduino Pro Micro.  When compiling this, use the "Arduino Micro" board designation.

// This uses The Arduino Joystick Library version 2.1.1 by Matthew Heironimus. Thank you Matthew!
// https://github.com/MHeironimus/ArduinoJoystickLibrary


#include <Joystick.h>

// Define pin assignments
const int pot1Pin = A0; // Potentiometer 1 connected to A0
const int pot2Pin = A1; // Potentiometer 2 connected to A1
const int button1Pin = 2; // Button 1 connected to digital pin 2
const int button2Pin = 3; // Button 2 connected to digital pin 3

// Create a Joystick object
Joystick_ Joystick(JOYSTICK_DEFAULT_REPORT_ID, JOYSTICK_TYPE_JOYSTICK,
                   2, 0,    // Number of buttons, number of hat switches
                   true,    // X-axis
                   true,    // Y-axis
                   false,   // Z-axis
                   false,   // Rx-axis
                   false,   // Ry-axis
                   false,   // Rz-axis
                   false,   // Rudder
                   false,   // Throttle
                   false,   // Accelerator
                   false,   // Brake
                   false);  // Steering

void setup() {
  // Initialize pins
  pinMode(pot1Pin, INPUT);
  pinMode(pot2Pin, INPUT);
  pinMode(button1Pin, INPUT_PULLUP);
  pinMode(button2Pin, INPUT_PULLUP);
  
  // Initialize the Joystick library
  Joystick.begin();
}

void loop() {
  // Read potentiometer values

  int pot1Value = 4* analogRead(pot1Pin); // Read analog value from potentiometer 1
  int pot2Value = 4*analogRead(pot2Pin); // Read analog value from potentiometer 2
  // The multipler of 4 corrects for the ADC resolution issue

  // Map the analog values to 8-bit range (0 to 255)
  int xPosition = map(pot1Value, 0, 1023, 0, 255);
  int yPosition = map(pot2Value, 0, 1023, 0, 255);

  // Send the potentiometer values as joystick X and Y positions
  Joystick.setXAxis(xPosition);
  Joystick.setYAxis(yPosition);

  // Read button states
  int button1State = digitalRead(button1Pin);
  int button2State = digitalRead(button2Pin);

  // Send button states to the joystick
  Joystick.setButton(0, button1State == LOW); // Button 1 (pressed = LOW)
  Joystick.setButton(1, button2State == LOW); // Button 2 (pressed = LOW)

  // Small delay to stabilize readings
  delay(10);
}